# :coding: utf-8
# :copyright: Copyright (c) 2024 ftrack

import maya.cmds as cmds

from ftrack_framework_core.plugin import BasePlugin
from ftrack_framework_core.exceptions.plugin import PluginValidationError


class MayaObjectExistsValidatorPlugin(BasePlugin):
    '''
    Plugin to validate if a object exists.
    '''

    name = 'maya_object_exists_validator'

    def run(self, store):
        '''
        Check object exists.
        '''
        component_name = self.options.get('component', 'main')
        # Pick the object from the store
        collected_chr_object = store['components'][component_name].get('collected_chr_object')
        if not cmds.objExists(collected_chr_object):
            raise PluginValidationError(
                message=f"Chr with name {collected_chr_object} doesn't exists"
            )
        self.logger.debug(f"Chr {collected_chr_object} exists.")
        store['components'][component_name]['valid_chr'] = True
